diff mtctest/rtp_play.c @ 13:c71801aa0039 default tip

themwi-test-mtc: increase maximum play length
author Mychaela Falconia <falcon@freecalypso.org>
date Tue, 29 Oct 2024 00:06:28 +0000
parents aa2ba9b432af
children
line wrap: on
line diff
--- a/mtctest/rtp_play.c	Sun Jun 09 05:00:35 2024 +0000
+++ b/mtctest/rtp_play.c	Tue Oct 29 00:06:28 2024 +0000
@@ -27,7 +27,7 @@
 
 int rtp_play_active;
 
-static uint8_t play_buffer[33*50*30];	/* max 30 s of GSM-FR play */
+static uint8_t play_buffer[33*50*180];	/* max 180 s of GSM-FR play */
 
 static uint32_t rtp_ssrc;
 static uint32_t rtp_out_ts;